EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'BuildSchedules_CreateOrUpdateURLTriggered',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Schedule_Id',
    /* Description_Text        */ 'Creates a URL-triggered build based on the specified parameters, or updates an existing schedule if one with the given ID already exists.',
    /* Remarks_Text            */ NULL
GO

IF OBJECT_ID('[BuildSchedules_CreateOrUpdateURLTriggered]') IS NOT NULL DROP PROCEDURE [BuildSchedules_CreateOrUpdateURLTriggered]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [BuildSchedules_CreateOrUpdateURLTriggered]
(
	@Schedule_Id INT = NULL OUT,
	@Schedule_Name VARCHAR(100),
	@Application_Id INT,
	@Url_AllowedIP_CSV VARCHAR(MAX),
	@Url_Username_Text VARCHAR(50),
	@Url_Password_Text VARCHAR(50),
	@ReleaseFilter_ReleaseType_Code CHAR(1),
	@ReleaseFilter_Pipeline_Id INT,
    @ReleaseFilter_Release_Number RELEASENUMBER,
    @BuildImporter_Configuration XML,
	@Active_Indicator YNINDICATOR
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Schedule_Id IS NULL
	BEGIN
		INSERT INTO [dbo].[BuildSchedules]
			([Schedule_Name]
			,[Application_Id]
			,[Active_Indicator]
			,[Schedule_Type]
			,[CreatedBy_User_Name]
			,[CreatedOn_Date]
			,[ModifiedBy_User_Name]
			,[ModifiedOn_Date]
			,[Url_AllowedIP_CSV]
			,[Url_Username_Text]
			,[Url_Password_Text]
			,[ReleaseFilter_ReleaseType_Code]
			,[ReleaseFilter_Pipeline_Id]
            ,[BuildImporter_Configuration]
            ,[ReleaseFilter_Release_Number])
		VALUES
			(@Schedule_Name
			,@Application_Id
			,@Active_Indicator
			,'URL Triggered'
			,dbo.Session_GetUserName()
			,GETUTCDATE()
			,dbo.Session_GetUserName()
			,GETUTCDATE()
			,@Url_AllowedIP_CSV
			,@Url_Username_Text
			,@Url_Password_Text
			,@ReleaseFilter_ReleaseType_Code
			,@ReleaseFilter_Pipeline_Id
            ,@BuildImporter_Configuration
            ,@ReleaseFilter_Release_Number)

		SET @Schedule_Id = SCOPE_IDENTITY()

		EXEC [Events_RaiseEvent] 'BSHNEW',@Application_Id,@Schedule_Id

	END
	ELSE
	BEGIN
		
		DECLARE @Schedule_Type VARCHAR(15)
		SELECT @Schedule_Type = [Schedule_Type] 
		  FROM [BuildSchedules]
		 WHERE [Schedule_Id] = @Schedule_Id
		
		IF @@ROWCOUNT=0 RAISERROR('BuildSchedule #%i does not exist.',16,1,@Schedule_Id) 
		IF @Schedule_Type <> 'URL Triggered' RAISERROR('Existing BuildSchedule #%i is not a URL Triggered schedule, it is %s.', 16, 1, @Schedule_Id, @Schedule_Type)
	
		UPDATE [dbo].[BuildSchedules]
		   SET [Schedule_Name] = @Schedule_Name
			  ,[Application_Id] = @Application_Id
			  ,[Active_Indicator] = @Active_Indicator
			  ,[ModifiedBy_User_Name] = dbo.Session_GetUserName()
			  ,[ModifiedOn_Date] = GETUTCDATE()
			  ,[Url_AllowedIP_CSV] = @Url_AllowedIP_CSV
			  ,[Url_Username_Text] = @Url_Username_Text
			  ,[Url_Password_Text] = @Url_Password_Text
			  ,[ReleaseFilter_ReleaseType_Code] = @ReleaseFilter_ReleaseType_Code
			  ,[ReleaseFilter_Pipeline_Id] = @ReleaseFilter_Pipeline_Id
              ,[BuildImporter_Configuration] = @BuildImporter_Configuration
              ,[ReleaseFilter_Release_Number] = @ReleaseFilter_Release_Number
		 WHERE [Schedule_Id] = @Schedule_Id

		EXEC [Events_RaiseEvent] 'BSHMOD',@Application_Id,@Schedule_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [BuildSchedules_CreateOrUpdateURLTriggered] TO [BuildMasterUser_Role]
