EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_RejectBuild',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Rejects the specified build.'
GO


IF OBJECT_ID('[Builds_RejectBuild]') IS NOT NULL DROP PROCEDURE [Builds_RejectBuild]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_RejectBuild]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
	@Build_Number BUILDNUMBER,
	@Rejection_Notes NVARCHAR(255) = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Build_Id INT
	SELECT @Build_Id = B.[Build_Id]
	  FROM [Builds] B
	       INNER JOIN [Releases] R
		           ON R.[Release_Id] = B.[Release_Id]
	 WHERE R.[Application_Id] = @Application_Id
	   AND R.[Release_Number] = @Release_Number
	   AND B.[Build_Number] = @Build_Number

	UPDATE [Builds]
	   SET [BuildStatus_Name] = 'Rejected'
		  ,[Rejection_Notes] = @Rejection_Notes
		  ,[Rejected_Date] = GETUTCDATE()
		  ,[RejectedBy_User_Name] = dbo.Session_GetUserName()
	 WHERE [Build_Id] = @Build_Id
	   AND [BuildStatus_Name] <> 'Deployed'

	EXEC [Events_RaiseEvent] 'BLDRJC', @Application_Id, @Release_Number, @Build_Number

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Builds_RejectBuild] TO [BuildMasterUser_Role]