EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Environments_ResequenceEnvironment',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Resequences the specified environment by placing it where another environment is sequenced'
GO


IF OBJECT_ID('[Environments_ResequenceEnvironment]') IS NOT NULL DROP PROCEDURE [Environments_ResequenceEnvironment]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Environments_ResequenceEnvironment]
(
	@Environment_Id INT,
	@New_Environment_Sequence INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Environment_Sequence INT
	SELECT @Environment_Sequence = [Display_Sequence]
	  FROM [Environments]
	 WHERE [Environment_Id] = @Environment_Id

	IF @Environment_Sequence IS NULL BEGIN
	   RAISERROR('Environment (ID=%i) was not found.', 16, 1, @Environment_Id)
	   RETURN
    END

	UPDATE [Environments] 
	   SET [Display_Sequence] = CASE
	       WHEN /* id */ [Environment_Id] = @Environment_Id THEN @New_Environment_Sequence

		   WHEN /* up */ @New_Environment_Sequence > @Environment_Sequence THEN CASE
		        WHEN [Display_Sequence] BETWEEN @Environment_Sequence AND @New_Environment_Sequence THEN [Display_Sequence] - 1
				ELSE [Display_Sequence] END
		   WHEN /* dn */ @New_Environment_Sequence < @Environment_Sequence THEN CASE
		        WHEN [Display_Sequence] BETWEEN @New_Environment_Sequence AND @Environment_Sequence THEN [Display_Sequence] + 1
				ELSE [Display_Sequence] END
		   ELSE @New_Environment_Sequence END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Environments_ResequenceEnvironment] TO [BuildMasterUser_Role]