EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'EventListeners_CreateOrUpdateEventListener',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'EventListener_Id',
    /* Description_Text        */ 'Creates or updates an event listener.'
GO

IF OBJECT_ID('[EventListeners_CreateOrUpdateEventListeners]') IS NOT NULL DROP PROCEDURE [EventListeners_CreateOrUpdateEventListeners]
GO
IF OBJECT_ID('[EventListeners_CreateOrUpdateEventListener]') IS NOT NULL DROP PROCEDURE [EventListeners_CreateOrUpdateEventListener]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [EventListeners_CreateOrUpdateEventListener]
(
	@EventListener_Description NVARCHAR(MAX),
	@EventListener_Configuration XML,
	@Owner_User_Name USERNAME,
	@Active_Indicator YNINDICATOR,

	@EventCodeList_Csv VARCHAR(MAX),
	@ApplicationIdList_Csv VARCHAR(MAX),
	@ApplicationGroupIdList_Csv VARCHAR(MAX),
	@PipelineStageNameList_Csv VARCHAR(MAX),

    @PipelineStageName_Delimeter VARCHAR(10) = NULL,

	@EventListener_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @EventListener_Id IS NULL BEGIN

		INSERT INTO [EventListeners]
		(
			[EventListener_Description],
			[EventListener_Configuration],
			[Owner_User_Name],
			[Active_Indicator]
		)
		VALUES
		(
			@EventListener_Description,
			@EventListener_Configuration,
			@Owner_User_Name,
			@Active_Indicator
		)
		
		SET @EventListener_Id = SCOPE_IDENTITY()

	END ELSE BEGIN

		UPDATE [EventListeners]
		   SET [EventListener_Description] = @EventListener_Description,
		       [EventListener_Configuration] = @EventListener_Configuration,
		       [Owner_User_Name] = @Owner_User_Name,
		       [Active_Indicator] = @Active_Indicator
		 WHERE [EventListener_Id] = @EventListener_Id

	END

	DELETE [EventListenerApplications] WHERE [EventListener_Id] = @EventListener_Id
	DELETE [EventListenerApplicationGroups] WHERE [EventListener_Id] = @EventListener_Id
	DELETE [EventListenerStages] WHERE [EventListener_Id] = @EventListener_Id
	DELETE [EventListenerEvents] WHERE [EventListener_Id] = @EventListener_Id

	INSERT INTO [EventListenerApplications] ([EventListener_Id],[Application_Id])
	SELECT @EventListener_Id, V.[Value_Text] 
	 FROM dbo.CsvToTable(@ApplicationIdList_Csv,',') V

	INSERT INTO [EventListenerApplicationGroups] ([EventListener_Id],[ApplicationGroup_Id])
	SELECT @EventListener_Id, V.[Value_Text] 
	 FROM dbo.CsvToTable(@ApplicationGroupIdList_Csv,',') V

	INSERT INTO [EventListenerStages] ([EventListener_Id],[PipelineStage_Name])
	SELECT @EventListener_Id, V.[Value_Text] 
	 FROM dbo.CsvToTable(@PipelineStageNameList_Csv,COALESCE(@PipelineStageName_Delimeter, ',')) V

	INSERT INTO [EventListenerEvents] ([EventListener_Id],[Event_Code])
	SELECT @EventListener_Id, V.[Value_Text] 
	 FROM dbo.CsvToTable(@EventCodeList_Csv, ',') V


	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [EventListeners_CreateOrUpdateEventListener] TO [BuildMasterUser_Role]