EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_CancelExecution',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ NULL,
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Stored procedure for internal use only.'
GO

IF OBJECT_ID('[dbo].[Executions_CancelExecution]') IS NOT NULL
	DROP PROCEDURE [dbo].[Executions_CancelExecution]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_CancelExecution]
(
	@Execution_Id INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @ExecutionStatus_Name VARCHAR(10)
	SET @ExecutionStatus_Name =
		(SELECT [ExecutionRunState_Code]
		   FROM [Executions]
		  WHERE [Execution_Id] = @Execution_Id)

	IF @ExecutionStatus_Name NOT IN ('P', 'X')
	BEGIN
		RAISERROR('This execution is not currently running; only executions in progress may be canceled.', 16, 1)
		RETURN
	END

	/* Pending executions immediately get failed; ones that are currently
	   executing will be canceled and picked up by the Plan Executer */
	UPDATE [Executions]
	   SET [CanceledBy_User_Name] = dbo.Session_GetUserName()
		  ,[CanceledOn_Date] = GETUTCDATE()
	 WHERE [Execution_Id] = @Execution_Id

	DECLARE @Application_Id INT
	SET @Application_Id =
		(SELECT [Application_Id]
		   FROM [Executions_Extended]
		  WHERE [Execution_Id] = @Execution_Id)

	IF @Application_Id IS NOT NULL
		EXEC [Events_RaiseEvent] 'EXECNL', @Application_Id, @Execution_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Executions_CancelExecution] TO [BuildMasterUser_Role]
GO
