EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_CreateLogScope',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Scope_Sequence',
    /* Description_Text        */ 'Creates a log scope.'
GO

IF OBJECT_ID('[Executions_CreateLogScope]') IS NOT NULL DROP PROCEDURE [Executions_CreateLogScope]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_CreateLogScope]
(
	@Execution_Id INT,
	@Scope_Name VARBINARY(MAX),
	@Parent_Scope_Sequence INT,
	@Start_Date DATETIME,
	@Scope_Sequence INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @NewScopes TABLE ([Scope_Sequence] INT)

	;WITH A AS(
		SELECT [Next_Sequence] = COALESCE(MAX([Scope_Sequence]), 0) + 1
          FROM [ScopedExecutionLogs]
         WHERE [Execution_Id] = @Execution_Id
	)
	INSERT INTO [ScopedExecutionLogs]
	(
		[Execution_Id],
		[Scope_Sequence],
		[Scope_Name],
		[Parent_Scope_Sequence],
		[Start_Date]
	)
	OUTPUT INSERTED.[Scope_Sequence] INTO @NewScopes
	SELECT @Execution_Id,
		   A.[Next_Sequence],
		   COALESCE(@Scope_Name, 0x),
		   @Parent_Scope_Sequence,
		   @Start_Date
	 FROM A

	SET @Scope_Sequence = (SELECT TOP 1 [Scope_Sequence] FROM @NewScopes)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Executions_CreateLogScope] TO [BuildMasterUser_Role]
