EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'LegacyExecutions_BeginAction',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'BuildExecution_ActionGroupAction_Id',
    /* Description_Text        */ 'Initiates execution of a specific action.'
GO


IF OBJECT_ID('[LegacyExecutions_BeginAction]') IS NOT NULL DROP PROCEDURE [LegacyExecutions_BeginAction]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [LegacyExecutions_BeginAction]
(
	@BuildExecution_DeploymentPlan_Id INT,
	@DeploymentPlanActionGroup_Sequence INT,
	@Action_Sequence INT,
	@Server_Name VARCHAR(50),
	@Attempt_Sequence INT,
	@VariableValues_Xml XML,
	@ExecutionAction_Description VARCHAR(500),
	@BuildExecution_ActionGroupAction_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	INSERT INTO [BuildExecution_ActionGroupActions]
	(
		[ExecutionStarted_Date],
		[ExecutionStatus_Name],
		[ExecutionAction_Description],
		[Original_Server_Name],
		[Original_Action_Sequence],
		[Attempt_Sequence],
		[WarningLogEntry_Indicator],
		[BuildExecution_DeploymentPlan_Id],
		[Original_DeploymentPlanActionGroup_Sequence]
	)
	VALUES
	(
		GETUTCDATE(),
		'Executing',
		@ExecutionAction_Description,
		@Server_Name,
		@Action_Sequence,
		@Attempt_Sequence,
		'N',
		@BuildExecution_DeploymentPlan_Id,
		@DeploymentPlanActionGroup_Sequence
	)

	SET @BuildExecution_ActionGroupAction_Id = SCOPE_IDENTITY()

	INSERT INTO [BuildExecution_ActionGroupActionVariableValues]
	(
		[BuildExecution_ActionGroupAction_Id],
		[Variable_Name],
		[Value_Text]
	)
	SELECT [BuildExecution_PlanAction_Id] = @BuildExecution_ActionGroupAction_Id,
	       [Variable_Name] = V.value('@N', 'VARCHAR(50)'),
	       V.value('@V', 'VARCHAR(MAX)')
	  FROM @VariableValues_Xml.nodes('/Vars/Var') AS _V(V)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [LegacyExecutions_BeginAction] TO [BuildMasterUser_Role]
